==> mozjs78_78.15.0.orig.tar.xz: firefox-78.15.0/js/src/tests/test262/built-ins/Array/prototype/concat/is-concat-spreadable-val-truthy.js <==
// Copyright (C) 2015 the V8 project authors. All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.
/*---
esid: sec-array.prototype.concat
description: >
    The `Symbol.isConcatSpreadable` property is defined and coerces to `true`
info: |
    1. Let O be ToObject(this value).
    2. ReturnIfAbrupt(O).
    3. Let A be ArraySpeciesCreate(O, 0).
    4. ReturnIfAbrupt(A).
    5. Let n be 0.
    6. Let items be a List whose first element is O and whose subsequent
       elements are, in left to right order, the arguments that were passed to
       this function invocation.
    7. Repeat, while items is not empty
      a. Remove the first element from items and let E be the value of the element.
      b. Let spreadable be IsConcatSpreadable(E).
      c. ReturnIfAbrupt(spreadable).
      d. If spreadable is true, then
         [...]

    ES6 22.1.3.1.1: Runtime Semantics: IsConcatSpreadable ( O )

    1. If Type(O) is not Object, return false.
    2. Let spreadable be Get(O, @@isConcatSpreadable).
    3. ReturnIfAbrupt(spreadable).
    4. If spreadable is not undefined, return ToBoolean(spreadable).
features: [Symbol, Symbol.isConcatSpreadable]
---*/

var item = {};
var result;

item[Symbol.isConcatSpreadable] = true;
result = [].concat(item);
assert.sameValue(result.length, 0);

item[Symbol.isConcatSpreadable] = 86;
result = [].concat(item);
assert.sameValue(result.length, 0);

item[Symbol.isConcatSpreadable] = 'string';
result = [].concat(item);
assert.sameValue(result.length, 0);

item[Symbol.isConcatSpreadable] = Symbol();
result = [].concat(item);
assert.sameValue(result.length, 0);

item[Symbol.isConcatSpreadable] = {};
result = [].concat(item);
assert.sameValue(result.length, 0);

reportCompare(0, 0);

==> mozjs115_115.21.0.orig.tar.xz: firefox-115.21.0/js/src/tests/test262/built-ins/Array/prototype/concat/is-concat-spreadable-val-truthy.js <==
// Copyright (C) 2015 the V8 project authors. All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.
/*---
esid: sec-array.prototype.concat
description: >
    The `Symbol.isConcatSpreadable` property is defined and coerces to `true`
info: |
    1. Let O be ToObject(this value).
    2. ReturnIfAbrupt(O).
    3. Let A be ArraySpeciesCreate(O, 0).
    4. ReturnIfAbrupt(A).
    5. Let n be 0.
    6. Let items be a List whose first element is O and whose subsequent
       elements are, in left to right order, the arguments that were passed to
       this function invocation.
    7. Repeat, while items is not empty
      a. Remove the first element from items and let E be the value of the element.
      b. Let spreadable be IsConcatSpreadable(E).
      c. ReturnIfAbrupt(spreadable).
      d. If spreadable is true, then
         [...]

    ES6 22.1.3.1.1: Runtime Semantics: IsConcatSpreadable ( O )

    1. If Type(O) is not Object, return false.
    2. Let spreadable be Get(O, @@isConcatSpreadable).
    3. ReturnIfAbrupt(spreadable).
    4. If spreadable is not undefined, return ToBoolean(spreadable).
features: [Symbol, Symbol.isConcatSpreadable]
---*/

var item = {};
var result;

item[Symbol.isConcatSpreadable] = true;
result = [].concat(item);
assert.sameValue(result.length, 0, 'The value of result.length is expected to be 0');

item[Symbol.isConcatSpreadable] = 86;
result = [].concat(item);
assert.sameValue(result.length, 0, 'The value of result.length is expected to be 0');

item[Symbol.isConcatSpreadable] = 'string';
result = [].concat(item);
assert.sameValue(result.length, 0, 'The value of result.length is expected to be 0');

item[Symbol.isConcatSpreadable] = Symbol();
result = [].concat(item);
assert.sameValue(result.length, 0, 'The value of result.length is expected to be 0');

item[Symbol.isConcatSpreadable] = {};
result = [].concat(item);
assert.sameValue(result.length, 0, 'The value of result.length is expected to be 0');

reportCompare(0, 0);
